@@ -4,8 +4,7 @@
 
 ;; Author: Vasilij Schneidermann <mail@vasilij.de>
 ;; URL: https://depp.brause.cc/nov.el
-;; Package-Version: 0.5.0
-;; Package-Revision: b37d9380752e
+;; Version: 0.5.0
 ;; Package-Requires: ((esxml "0.3.6") (emacs "25.1"))
 ;; Keywords: hypermedia, multimedia, epub
 
@@ -794,15 +793,18 @@ Takes an optional COUNT, goes forward if COUNT is negative."
   (when target
     (let ((pos (point-min))
           done)
-      (while (and (not done)
-                  (setq pos (next-single-property-change pos 'shr-target-id)))
+      (while (and (not done) pos)
         (let ((property (get-text-property pos 'shr-target-id)))
-          (when (or (equal property target)
-                    ;; NOTE: as of Emacs 28.1 this may be a list of targets
-                    (and (consp property) (member target property)))
-            (goto-char pos)
-            (recenter (1- (max 1 scroll-margin)))
-            (setq done t))))
+          (if (or (equal property target)
+                  ;; NOTE: as of Emacs 28.1 this may be a list of targets
+                  (and (consp property) (member target property)))
+              (progn
+                (goto-char pos)
+                (recenter (1- (max 1 scroll-margin)))
+                (setq done t))
+            ;; NOTE: to catch the case of cursor starting out at the
+            ;; `shr-target-id' property, change pos *after* checking
+            (setq pos (next-single-property-change pos 'shr-target-id)))))
       (when (not done)
         (error "Couldn't locate target")))))
 
@@ -1002,6 +1004,7 @@ See also `nov-bookmark-make-record'."
 
 ;;; Org interop
 
+;;;###autoload
 (defun nov-org-link-follow (path)
   "Follow nov: link designated by PATH."
   (if (string-match "^\\(.*\\)::\\([0-9]+\\):\\([0-9]+\\)$" path)
@@ -1011,6 +1014,7 @@ See also `nov-bookmark-make-record'."
         (nov--find-file file index point))
     (error "Invalid nov.el link")))
 
+;;;###autoload
 (defun nov-org-link-store ()
   "Store current EPUB location as nov: link."
   (when (and (eq major-mode 'nov-mode) nov-file-name)
@@ -1024,21 +1028,28 @@ See also `nov-bookmark-make-record'."
                         nov-file-name
                         nov-documents-index
                         (point)))
-          (description (format "EPUB file at %s" nov-file-name)))
+          (description (or (alist-get 'title nov-metadata)
+                           (format "EPUB file at %s" nov-file-name))))
       (funcall org-store-props-function
                :type "nov"
                :link link
+               :author (alist-get 'creator nov-metadata)
+               :language (alist-get 'language nov-metadata)
+               :initial (alist-get 'description nov-metadata)
+               :publisher (alist-get 'publisher nov-metadata)
                :description description))))
 
-(cond
- ((fboundp 'org-link-set-parameters)
-  (org-link-set-parameters
-   "nov"
-   :follow 'nov-org-link-follow
-   :store 'nov-org-link-store))
- ((fboundp 'org-add-link-type)
-  (org-add-link-type "nov" 'nov-org-link-follow)
-  (add-hook 'org-store-link-functions 'nov-org-link-store)))
+;;;###autoload
+(with-eval-after-load 'org
+  (cond
+   ((fboundp 'org-link-set-parameters)
+    (org-link-set-parameters
+     "nov"
+     :follow 'nov-org-link-follow
+     :store 'nov-org-link-store))
+   ((fboundp 'org-add-link-type)
+    (org-add-link-type "nov" 'nov-org-link-follow)
+    (add-hook 'org-store-link-functions 'nov-org-link-store))))
 
 
 ;;; Imenu interop
